# Copyright 1999-2010 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: /var/cvsroot/gentoo-x86/net-misc/nx/nx-3.4.0-r1.ebuild,v 1.1 2010/02/09 23:25:04 voyageur Exp $

EAPI=2

MY_PVV=${PV/_p/-}
MY_PV=${PV/_p*/}
NXAGENT_VER="11"
NXAUTH_VER="3"


inherit autotools eutils multilib

DESCRIPTION="NX compression technology core libraries"
HOMEPAGE="http://www.nomachine.com/developers.php"

URI_BASE="http://web04.nomachine.com/download/${MY_PV}/sources"
SRC_NX_X11="nx-X11-${MY_PVV}.tar.gz"
SRC_NXAGENT="nxagent-${MY_PV}-${NXAGENT_VER}.tar.gz"
SRC_NXAUTH="nxauth-${MY_PV}-${NXAUTH_VER}.tar.gz"

SRC_URI="$URI_BASE/$SRC_NX_X11 $URI_BASE/$SRC_NXAGENT $URI_BASE/$SRC_NXAUTH"

LICENSE="GPL-2"
SLOT="0"
KEYWORDS="~amd64 ~x86"
IUSE=""

RDEPEND="media-libs/freetype
	x11-libs/libXcomposite
	x11-libs/libXfixes
	x11-libs/libXpm
	>=media-libs/jpeg-6b-r4
	>=media-libs/libpng-1.2.8
	>=sys-libs/zlib-1.2.3
	>=net-misc/nxcomp-${MY_PV}
	>=net-misc/nxcompext-${MY_PV}
	>=net-misc/nxcompshad-${MY_PV}"

DEPEND="${RDEPEND}
		x11-misc/gccmakedep
		x11-misc/imake
		x11-proto/inputproto"

S=${WORKDIR}/${PN}

src_prepare() {
	# Fix sandbox violation
	epatch "${FILESDIR}"/nx-x11-1.5.0-tmp-exec.patch
	# Use System nxcomp
	epatch "${FILESDIR}"/01_build_nx-X11_without_nxcomp.dpatch
	# use System nxcompshad
	epatch "${FILESDIR}"/02_dont_build_nxcompshad.dpatch
	# Rename the nx patched x11 libs
	epatch "${FILESDIR}"/85_nx-X11_debian-ld.dpatch
	# search in system rgb path for the rgb file
	epatch "${FILESDIR}"/86_set_rgb_path.dpatch
	# Change system security policy path
	epatch "${FILESDIR}"/87_set_securitypolicy_path.dpatch
	# set location for the X0 keyboard file
	epatch "${FILESDIR}"/90_set_X0-config_path.dpatch
	# Export Keyboard config
	epatch "${FILESDIR}"/93_export_remote_keyboard_config.dpatch
	# Fix Makefiles for external libs
	epatch "${FILESDIR}"/95_fix_Imakefile.dpatch
	# Add utf8 support to the clipboard in nx session
	epatch "${FILESDIR}"/nx-X11-utf8_copy_clipboard.patch
	# prevent sending COMPOUND_TEXT to client
	epatch "${FILESDIR}"/nx-X11-dimbor.patch
	# add a timeout to closewindow for wine
	epatch "${FILESDIR}"/nxa_wine_close_delay.patch
	# add locale support to nxagent
	epatch "${FILESDIR}"/nxagent.MotifWMHints_Utf8Names.dimbor.patch
	# dont crash on to big pixmaps
	epatch "${FILESDIR}"/createpixmap_bounds_check.patch
	# remove nomachine branding
	epatch "${FILESDIR}"/unbranded.diff
	# find nx header
	epatch "${FILESDIR}"/nx-X11-3.4.0-Imake-fix-1.patch



	# From xorg-x11-6.9.0-r3.ebuild
	cd "${S}"
	[ -e programs/Xserver/hw/nxagent ] || cp -r nxagent/programs/Xserver/hw/nxagent programs/Xserver/hw/
	HOSTCONF="config/cf/host.def"
	echo "#define CcCmd $(tc-getCC)" >> ${HOSTCONF}
	echo "#define OptimizedCDebugFlags ${CFLAGS} GccAliasingArgs" >> ${HOSTCONF}
	echo "#define OptimizedCplusplusDebugFlags ${CXXFLAGS} GccAliasingArgs" >> ${HOSTCONF}
}

src_compile() {
	# Again, from xorg-x11-6.9.0-r3.ebuild
	unset MAKE_OPTS
	FAST=1 emake -j1 World WORLDOPTS="" MAKE="make" || die "nx-X11 emake failed"
}

src_install() {
	dobin "${S}"/programs/Xserver/nxagent
	dobin "${S}"/programs/nxauth/nxauth

	dolib.so "${S}"/lib/X11/libX11-nx.so*
	dolib.so "${S}"/lib/Xext/libXext-nx.so*
	dolib.so "${S}"/lib/Xrender/libXrender-nx.so*

	insinto /usr/include/nx
	doins "${S}"/programs/Xserver/hw/nxagent/*.h
	doins "${S}"/programs/Xserver/include/dix.h
	doins -r "${S}"/exports/include/*

	insinto /etc/nxagent
	doins "${FILESDIR}"/nxagent.keyboard

	insinto /usr/share/nxagent
	doins "${FILESDIR}"/rgb
	doins "${S}"/programs/Xserver/Xext/SecurityPolicy

	insinto /usr/share/pixmaps
	doins "${S}"/programs/Xserver/hw/nxagent/nxagent.xpm

	doman "${FILESDIR}"/nxagent.1
}
